@@ -31,16 +31,9 @@ DisplayManager::DisplayManager(QObject *parent)
     : QObject(parent)
     , m_gsettings(Utils::SettingsPtr("com.deepin.dde.dock.mainwindow", "/com/deepin/dde/dock/mainwindow/", this))
     , m_onlyInPrimary(Utils::SettingValue("com.deepin.dde.dock.mainwindow", "/com/deepin/dde/dock/mainwindow/", "onlyShowPrimary", false).toBool())
-    , m_displayInter(nullptr)
 {
     connect(qApp, &QApplication::primaryScreenChanged, this, &DisplayManager::primaryScreenChanged);
-    if (Utils::IS_WAYLAND_DISPLAY) {
-        m_displayInter = new DisplayInter("com.deepin.daemon.Display", "/com/deepin/daemon/Display",QDBusConnection::sessionBus(), this);
-        connect(m_displayInter, &__Display::PrimaryChanged, this, &DisplayManager::dockInfoChanged);
-        connect(m_displayInter, &__Display::DisplayModeChanged, this, &DisplayManager::dockInfoChanged);
-    } else {
-        connect(qApp, &QApplication::primaryScreenChanged, this, &DisplayManager::dockInfoChanged);
-    }
+    connect(qApp, &QApplication::primaryScreenChanged, this, &DisplayManager::dockInfoChanged);
     connect(qApp, &QGuiApplication::screenAdded, this, &DisplayManager::screenCountChanged);
     connect(qApp, &QGuiApplication::screenRemoved, this, &DisplayManager::screenCountChanged);
 
@@ -152,8 +145,6 @@ bool DisplayManager::isCopyMode()
  */
 void DisplayManager::updateScreenDockInfo()
 {
-    // TODO 目前仅仅支持双屏，如果超过双屏，会出现异常，这里可以考虑做成通用的处理规则
-
     // 先清除原先的数据，然后再更新
     m_screenPositionMap.clear();
 
@@ -173,7 +164,7 @@ void DisplayManager::updateScreenDockInfo()
     // 仅显示在主屏时的处理
     if (m_onlyInPrimary) {
         for (auto s : m_screens) {
-            if (Utils::IS_WAYLAND_DISPLAY ? !s->model().contains(m_displayInter->primary()) : s != qApp->primaryScreen()) {
+            if (s != qApp->primaryScreen()) {
                 QMap <Position, bool> map;
                 map.insert(Position::Top, false);
                 map.insert(Position::Bottom, false);
@@ -189,7 +180,7 @@ void DisplayManager::updateScreenDockInfo()
         return;
     }
 
-    // 适配多个屏幕的情况
+    // 适配任意多个屏幕的情况
     for(auto s : m_screens) {
         QList<QScreen *> otherScreens = m_screens;
         otherScreens.removeAll(s);
@@ -290,6 +281,7 @@ void DisplayManager::screenCountChanged()
     for (auto s : to_remove_list) {
         disconnect(s);
         m_screens.removeOne(s);
+        Q_EMIT screenRemoved(s);
     }
 
     // 创建关联
@@ -312,6 +304,7 @@ void DisplayManager::screenCountChanged()
         connect(s, &QScreen::refreshRateChanged, this, &DisplayManager::dockInfoChanged);
 
         m_screens.append(s);
+        Q_EMIT screenAdded(s);
     }
 
     // 屏幕数量发生变化，应该刷新一下任务栏的显示
