@@ -24,6 +24,8 @@
 #include "utils.h"
 #include "displaymanager.h"
 
+#include <DWindowManagerHelper>
+
 #include <QWidget>
 #include <QScreen>
 #include <QEvent>
@@ -45,10 +47,9 @@ const QString OnlyShowPrimary = "onlyShowPrimary";
 // 保证以下数据更新顺序(大环节顺序不要变，内部还有一些小的调整，比如任务栏显示区域更新的时候，里面内容的布局方向可能也要更新...)
 // Monitor数据－＞屏幕是否可停靠更新－＞监视唤醒区域更新，任务栏显示区域更新－＞拖拽区域更新－＞通知后端接口，通知窗管
 
-MultiScreenWorker::MultiScreenWorker(QWidget *parent, DWindowManagerHelper *helper)
+MultiScreenWorker::MultiScreenWorker(QWidget *parent)
     : QObject(parent)
     , m_parent(parent)
-    , m_wmHelper(helper)
     , m_eventInter(new XEventMonitor("com.deepin.api.XEventMonitor", "/com/deepin/api/XEventMonitor", QDBusConnection::sessionBus(), this))
     , m_extralEventInter(new XEventMonitor("com.deepin.api.XEventMonitor", "/com/deepin/api/XEventMonitor", QDBusConnection::sessionBus(), this))
     , m_touchEventInter(new XEventMonitor("com.deepin.api.XEventMonitor", "/com/deepin/api/XEventMonitor", QDBusConnection::sessionBus(), this))
@@ -178,7 +179,7 @@ void MultiScreenWorker::updateDaemonDockSize(int dockSize)
         m_dockInter->setWindowSizeEfficient(uint(dockSize));
 }
 
-void MultiScreenWorker::handleDbusSignal(QDBusMessage msg)
+void MultiScreenWorker::handleDBusSignal(QDBusMessage msg)
 {
     QList<QVariant> arguments = msg.arguments();
     // 参数固定长度
@@ -276,6 +277,10 @@ void MultiScreenWorker::updateDisplay()
     //3、任务栏高度或宽度调整的拖拽区域，
     //4、通知窗管的任务栏显示区域信息，
     //5、通知后端的任务栏显示区域信息
+
+    // wayland环境下，QScreen销毁也就是拔掉显示器的时候，会隐藏当前窗口，这里手动显示一次
+    parent()->setVisible(true);
+
     if (DIS_INS->screens().size() == 0) {
         qWarning() << "No Screen Can Display.";
         return;
@@ -295,10 +300,12 @@ void MultiScreenWorker::onWindowSizeChanged(uint value)
     m_monitorUpdateTimer->start();
 }
 
-void MultiScreenWorker::primaryScreenChanged()
+void MultiScreenWorker::primaryScreenChanged(QScreen *screen)
 {
+    Q_ASSERT(screen);
+
     // 先更新主屏信息
-    m_ds.updatePrimary(DIS_INS->primary());
+    m_ds.updatePrimary(screen->name());
 
     // 无效值
     if (DIS_INS->screenRawHeight() == 0 || DIS_INS->screenRawWidth() == 0) {
@@ -350,9 +357,8 @@ void MultiScreenWorker::onPositionChanged(const Position &position)
     Position lastPos = m_position;
     if (lastPos == position)
         return;
-#ifdef QT_DEBUG
-    qDebug() << "position change from: " << lastPos << " to: " << position;
-#endif
+
+    qInfo() << "position changed from: " << lastPos << " to: " << position;
     m_position = position;
 
     // 更新鼠标拖拽样式，在类内部设置到qApp单例上去
@@ -380,7 +386,7 @@ void MultiScreenWorker::onDisplayModeChanged(const DisplayMode &displayMode)
     if (displayMode == m_displayMode)
         return;
 
-    qInfo() << "display mode change:" << displayMode;
+    qInfo() << "display mode changed:" << displayMode;
 
     m_displayMode = displayMode;
 
@@ -411,7 +417,7 @@ void MultiScreenWorker::onHideModeChanged(const HideMode &hideMode)
     if (m_hideMode == hideMode)
         return;
 
-    qInfo() << "hidemode change:" << hideMode;
+    qInfo() << "hidemode changed:" << hideMode;
 
     m_hideMode = hideMode;
 
@@ -442,7 +448,7 @@ void MultiScreenWorker::onHideStateChanged(const Dock::HideState &state)
         m_ds.updateDockedScreen(getValidScreen(m_position));
     }
 
-    qInfo() << "hidestate change:" << m_hideMode << m_hideState;
+    qInfo() << "hidestate changed:" << m_hideMode << m_hideState;
 
     if (m_hideMode == HideMode::KeepShowing
             || ((m_hideMode == HideMode::KeepHidden || m_hideMode == HideMode::SmartHide) && m_hideState == HideState::Show)) {
@@ -451,13 +457,15 @@ void MultiScreenWorker::onHideStateChanged(const Dock::HideState &state)
         // 如果鼠标正在任务栏要显示的区域,就可以不用隐藏(相当于智能隐藏被唤醒一样)
         if (getDockShowGeometry(m_ds.current(), m_position, m_displayMode).contains(QCursor::pos()))
             return;
+
         displayAnimation(m_ds.current(), AniAction::Hide);
     }
 }
 
 void MultiScreenWorker::onOpacityChanged(const double value)
 {
-    if (int(m_opacity * 100) == int(value * 100)) return;
+    if (int(m_opacity * 100) == int(value * 100))
+        return;
 
     m_opacity = value;
 
@@ -660,11 +668,13 @@ void MultiScreenWorker::onRequestUpdateRegionMonitor()
 
 void MultiScreenWorker::onRequestUpdateFrontendGeometry()
 {
-    const QRect rect = dockRectWithoutScale(m_ds.current(), m_position, m_hideMode, m_displayMode);
+    HideMode hideMode = HideMode::KeepShowing;
+    // 当设置为一直隐藏模式时，按照当前隐藏的状态去设置任务栏区域信息，否则，按照当前显示模式去设置
+    if (m_hideMode == HideMode::KeepHidden) {
+        hideMode = m_hideMode;
+    }
 
-    //!!! 智能隐藏模式下隐藏之后不需要在设置一次，否则会导致HideState属性循环变化
-    if (m_hideMode == HideMode::SmartHide && m_currentHideState == HideState::Hide)
-        return;
+    const QRect rect = dockRectWithoutScale(m_ds.current(), m_position, hideMode, m_displayMode);
 
 #ifdef QT_DEBUG
     qDebug() << rect;
@@ -704,6 +714,40 @@ bool MultiScreenWorker::isCopyMode()
     return true;
 }
 
+/**
+ * @brief MultiScreenWorker::getScreenRect
+ * @param s
+ * @param ratio
+ * @return 返回屏幕 \s 的原始尺寸，\ratio 为屏幕 \s 的当前缩放值
+ */
+QRect MultiScreenWorker::getScreenRect(QScreen *s)
+{
+    if (!s)
+        return QRect();
+
+    auto geo = s->geometry();
+    QRect screenRect;
+    screenRect.setX(geo.x());
+    screenRect.setY(geo.y());
+    screenRect.setWidth(static_cast<int>(geo.width() * s->devicePixelRatio()));
+    screenRect.setHeight(static_cast<int>(geo.height() * s->devicePixelRatio()));
+
+    /* QScreen的handle会返回显示器缩放之前的分辨率
+    * 比如1920*1080,调整缩放为1.25，那么QScreen::geometry返回的为QSize(1536, 864),QScreen::handle()->geometry()返回的为QSize(1920, 1080);
+    *
+    * @note 但在特殊情况下，比如频繁插拔显示器时，小概率出现handle返回的值并不等于缩放前的分辨率的情况，从而导致任务栏位置设置出错，
+    * 这里仍然直接使用geometry*ratio的方式,去获取缩放前的分辨率
+    * 但考虑到缩放值类型为double，可能在高分屏下计算得到的尺寸和通过handle函数的原始尺寸有1像素的误差，
+    * 所以计算完毕后和handle比对一下，如果存在1像素的误差，则仍然使用handle函数，否则使用QScreen::geometry() * ratio
+    */
+    auto size = s->handle()->geometry().size() - screenRect.size();
+    if (Q_LIKELY(size.width() <= 1 && size.height() <= 1)) {
+        screenRect = s->handle()->geometry();
+    }
+
+    return screenRect;
+}
+
 /**
  * @brief 这里用到xcb去设置任务栏的高度，比较特殊，参考_NET_WM_STRUT_PARTIAL属性
  * 在屏幕旋转后，所有参数以控制中心自定义设置里主屏显示的图示为准（旋转不用特殊处理）
@@ -718,6 +762,8 @@ void MultiScreenWorker::onRequestNotifyWindowManager()
     if ((!DIS_INS->isCopyMode() && m_ds.current() != m_ds.primary()) || m_hideMode != HideMode::KeepShowing) {
         lastRect = QRect();
 
+        qInfo() << "clear wm struct";
+
         if (Utils::IS_WAYLAND_DISPLAY) {
             QList<QVariant> varList;
             varList.append(0);//dock位置
@@ -759,25 +805,25 @@ void MultiScreenWorker::onRequestNotifyWindowManager()
         switch (m_position) {
         case Position::Top:
             varList[0] = 1;
-            varList[1] = dockGeometry.y() + dockGeometry.height() + WINDOWMARGIN * ratio;
+            varList[1] = dockGeometry.height();
             varList[2] = dockGeometry.x();
             varList[3] = dockGeometry.x() + dockGeometry.width();
             break;
         case Position::Bottom:
             varList[0] = 3;
-            varList[1] = DIS_INS->screenRawHeight() - dockGeometry.y() + WINDOWMARGIN * ratio;
+            varList[1] = dockGeometry.height();
             varList[2] = dockGeometry.x();
             varList[3] = dockGeometry.x() + dockGeometry.width();
             break;
         case Position::Left:
             varList[0] = 0;
-            varList[1] = dockGeometry.x() + dockGeometry.width() + WINDOWMARGIN * ratio;
+            varList[1] = dockGeometry.width();
             varList[2] = dockGeometry.y();
             varList[3] = dockGeometry.y() + dockGeometry.height();
             break;
         case Position::Right:
             varList[0] = 2;
-            varList[1] = DIS_INS->screenRawWidth() - dockGeometry.x() + WINDOWMARGIN * ratio;
+            varList[1] = dockGeometry.width();
             varList[2] = dockGeometry.y();
             varList[3] = dockGeometry.y() + dockGeometry.height();
             break;
@@ -909,7 +955,6 @@ void MultiScreenWorker::initMembers()
 
 void MultiScreenWorker::initConnection()
 {
-    connect(qApp, &QApplication::primaryScreenChanged, this, &MultiScreenWorker::primaryScreenChanged);
     connect(DIS_INS, &DisplayManager::primaryScreenChanged, this, &MultiScreenWorker::primaryScreenChanged);
     connect(DIS_INS, &DisplayManager::screenInfoChanged, this, &MultiScreenWorker::requestUpdateMonitorInfo);
 
@@ -934,7 +979,7 @@ void MultiScreenWorker::initConnection()
                                           "org.freedesktop.DBus.Properties",
                                           "PropertiesChanged",
                                           "sa{sv}as",
-                                          this, SLOT(handleDbusSignal(QDBusMessage)));
+                                          this, SLOT(handleDBusSignal(QDBusMessage)));
 #endif
 
     connect(this, &MultiScreenWorker::requestUpdateFrontendGeometry, this, &MultiScreenWorker::onRequestUpdateFrontendGeometry);
@@ -1063,7 +1108,7 @@ void MultiScreenWorker::displayAnimation(const QString &screen, const Position &
     ani->setEasingCurve(QEasingCurve::InOutCubic);
 
 #ifndef DISABLE_SHOW_ANIMATION
-    const bool composite = m_wmHelper->hasComposite(); // 判断是否开启特效模式
+    const bool composite = DWindowManagerHelper::instance()->hasComposite(); // 判断是否开启特效模式
     const int duration = composite ? ANIMATIONTIME : 0;
 #else
     const int duration = 0;
@@ -1168,7 +1213,7 @@ void MultiScreenWorker::changeDockPosition(QString fromScreen, QString toScreen,
     ani1->setEasingCurve(QEasingCurve::InOutCubic);
     ani2->setEasingCurve(QEasingCurve::InOutCubic);
 
-    const bool composite = m_wmHelper->hasComposite();
+    const bool composite = DWindowManagerHelper::instance()->hasComposite();
 #ifndef DISABLE_SHOW_ANIMATION
     const int duration = composite ? ANIMATIONTIME : 0;
 #else
@@ -1294,6 +1339,7 @@ void MultiScreenWorker::resetDockScreen()
       */
     parent()->setFixedSize(dockRect(m_ds.current()).size());
     parent()->setGeometry(dockRect(m_ds.current()));
+    qDebug() << "update dock geometry: " << dockRect(m_ds.current());
     parent()->panel()->setFixedSize(dockRect(m_ds.current()).size());
     parent()->panel()->move(0, 0);
 }
@@ -1464,18 +1510,21 @@ void MultiScreenWorker::checkXEventMonitorService()
     }
 }
 
-QRect MultiScreenWorker::getDockShowMinGeometry(const QString &screenName, bool withoutScale)
+/**
+ * @brief MultiScreenWorker::getDockShowMinGeometry
+ * @param screenName
+ * @return 如果dock在当前screenName对应的屏幕上显示，返回其在最小 高/宽 度(也就是40,最大值为100)的rect区域
+ */
+QRect MultiScreenWorker::getDockShowMinGeometry(const QString &screenName)
 {
     QRect rect;
-    const double ratio = withoutScale ? 1 : qApp->devicePixelRatio();
-    const int margin = static_cast<int>((m_displayMode == DisplayMode::Fashion ? 10 : 0) * (withoutScale ? qApp->devicePixelRatio() : 1));
+    const double ratio = qApp->devicePixelRatio();
+    const int margin = static_cast<int>((m_displayMode == DisplayMode::Fashion ? 10 : 0) * qApp->devicePixelRatio());
     const int dockSize = 40;
 
     for (auto s : DIS_INS->screens()) {
         if (s->name() == screenName) {
-            // 拿到当前显示器缩放之前的分辨率
-            QRect screenRect = s->handle()->geometry();
-
+            const QRect screenRect = getScreenRect(s);
             switch (m_position) {
             case Position::Top:
                 rect.setX(static_cast<int>(screenRect.x() + margin));
@@ -1507,6 +1556,18 @@ QRect MultiScreenWorker::getDockShowMinGeometry(const QString &screenName, bool
     return rect;
 }
 
+bool MultiScreenWorker::launcherVisible()
+{
+    return m_launcherInter->isValid() ? m_launcherInter->visible() : false;
+}
+
+void MultiScreenWorker::setLauncherVisble(bool isVisible)
+{
+    if (m_launcherInter->isValid()) {
+        isVisible ? m_launcherInter->Show() : m_launcherInter->Hide();
+    }
+}
+
 /**
  * @brief 获取任务栏显示时的参数。目前多屏情况下缩放保持一致，如果后续缩放规则修改，这里需要重新调整
  *
@@ -1525,9 +1586,7 @@ QRect MultiScreenWorker::getDockShowGeometry(const QString &screenName, const Po
 
     for (auto s : DIS_INS->screens()) {
         if (s->name() == screenName) {
-            // 拿到当前显示器缩放之前的分辨率
-            QRect screenRect = s->handle()->geometry();
-
+            const QRect screenRect = getScreenRect(s);
             switch (pos) {
             case Position::Top:
                 rect.setX(static_cast<int>(screenRect.x() + margin));
@@ -1576,9 +1635,7 @@ QRect MultiScreenWorker::getDockHideGeometry(const QString &screenName, const Po
 
     for (auto s : DIS_INS->screens()) {
         if (s->name() == screenName) {
-            // 拿到当前显示器缩放之前的分辨率
-            QRect screenRect = s->handle()->geometry();
-
+            const QRect screenRect = getScreenRect(s);
             switch (pos) {
             case Position::Top:
                 rect.setX(static_cast<int>(screenRect.x() + margin));
@@ -1803,32 +1860,33 @@ void MultiScreenWorker::tryToShowDock(int eventX, int eventY)
 ScreenChangeMonitor::ScreenChangeMonitor(DockScreen *ds, QObject *parent)
     : QObject (parent)
 {
-    connect(qApp, &QApplication::primaryScreenChanged, this, [ this, ds ](QScreen *primaryScreen) {
-        if (!primaryScreen)
-            return;
+    #define DATETOSTRING(date) date.toString("hh:mm:ss:zzz")
+
+    connect(DIS_INS, &DisplayManager::primaryScreenChanged, this, [ this, ds ](QScreen *primaryScreen) {
+        Q_ASSERT(primaryScreen);
 
         // 在screenAdded之后，又会发送一次主屏幕的变更的信息
-        qInfo() << "primary Screen Changed,primary Screen" << primaryScreen->name();
+        qInfo() << "primary screen changed, primary Screen" << primaryScreen->name();
         if (changedInSeconds())
             return;
 
         m_lastScreenName = ds->current();
         m_changePrimaryName = primaryScreen->name();
         m_changeTime = QDateTime::currentDateTime();
-        qInfo() << "primary Changed Info:lastScreen:" << m_lastScreenName << "changeTime:" << m_changeTime;
+        qInfo() << "primary changed from: " << m_lastScreenName << "to: " << DATETOSTRING(m_changeTime);
     });
-    connect(qApp, &QApplication::screenAdded, this, [ this ](QScreen *newScreen) {
+    connect(DIS_INS, &DisplayManager::screenAdded, this, [ this ](QScreen *newScreen) {
         if (newScreen) {
             m_newScreenName = newScreen->name();
             m_newTime = QDateTime::currentDateTime();
-            qInfo() <<"screen added:" << m_newScreenName << ", added time:" << m_newTime;
+            qInfo() <<"screen added:" << m_newScreenName << ", time:" << DATETOSTRING(m_newTime);
         }
     });
-    connect(qApp, &QApplication::screenRemoved, this, [ this ](QScreen *rmScreen) {
+    connect(DIS_INS, &DisplayManager::screenRemoved, this, [ this ](QScreen *rmScreen) {
         if (rmScreen) {
             m_removeScreenName = rmScreen->name();
             m_removeTime = QDateTime::currentDateTime();
-            qInfo() <<"screen removed:" << m_removeScreenName << ", removed time:" << m_removeTime;
+            qInfo() <<"screen removed:" << m_removeScreenName << ", time:" << DATETOSTRING(m_removeTime);
         }
     });
 }
