@@ -31,10 +31,9 @@
 #include <com_deepin_api_xeventmonitor.h>
 #include <com_deepin_dde_launcher.h>
 
-#include <DWindowManagerHelper>
-
 #include <QObject>
 #include <QFlag>
+#include <QDebug>
 
 #define WINDOWMARGIN ((m_displayMode == Dock::Efficient) ? 0 : 10)
 #define ANIMATIONTIME 300
@@ -79,6 +78,7 @@ public:
 
     void updateDockedScreen(const QString &screenName)
     {
+        qInfo() << "update docked screen" << screenName;
         m_lastScreen = m_currentScreen;
         m_currentScreen = screenName;
     }
@@ -128,7 +128,7 @@ public:
 
     typedef QFlags<RunState> RunStates;
 
-    MultiScreenWorker(QWidget *parent, DWindowManagerHelper *helper);
+    MultiScreenWorker(QWidget *parent);
 
     void initShow();
 
@@ -147,7 +147,10 @@ public:
 
     QRect dockRect(const QString &screenName, const Position &pos, const HideMode &hideMode, const DisplayMode &displayMode);
     QRect dockRect(const QString &screenName);
-    QRect getDockShowMinGeometry(const QString &screenName, bool withoutScale = false);
+    QRect getDockShowMinGeometry(const QString &screenName);
+
+    bool launcherVisible();
+    void setLauncherVisble(bool isVisible);
 
 signals:
     void opacityChanged(const quint8 value) const;
@@ -171,9 +174,10 @@ public slots:
     void onAutoHideChanged(bool autoHide);
     void updateDaemonDockSize(int dockSize);
     void onRequestUpdateRegionMonitor();
-    void handleDbusSignal(QDBusMessage);
 
 private slots:
+    void handleDBusSignal(QDBusMessage);
+
     // Region Monitor
     void onRegionMonitorChanged(int x, int y, const QString &key);
     void onExtralRegionMonitorChanged(int x, int y, const QString &key);
@@ -185,7 +189,7 @@ private slots:
     void updateDisplay();
 
     void onWindowSizeChanged(uint value);
-    void primaryScreenChanged();
+    void primaryScreenChanged(QScreen *screen);
     void updateParentGeometry(const QVariant &value, const Position &pos);
     void updateParentGeometry(const QVariant &value);
 
@@ -213,6 +217,7 @@ private slots:
 
 private:
     MainWindow *parent();
+
     // 初始化数据信息
     void initMembers();
     void initDBus();
@@ -243,10 +248,10 @@ private:
     bool onScreenEdge(const QString &screenName, const QPoint &point);
     const QPoint rawXPosition(const QPoint &scaledPos);
     static bool isCopyMode();
+    QRect getScreenRect(QScreen *s);
 
 private:
     QWidget *m_parent;
-    DWindowManagerHelper *m_wmHelper;
 
     // monitor screen
     XEventMonitor *m_eventInter;
@@ -299,6 +304,7 @@ class ScreenChangeMonitor : public QObject
 public:
     ScreenChangeMonitor(DockScreen *ds, QObject *parent);
     ~ScreenChangeMonitor();
+
     bool needUsedLastScreen() const;
     const QString lastScreen();
 
@@ -310,8 +316,10 @@ private:
 
     QString m_changePrimaryName;
     QDateTime m_changeTime;
+
     QString m_newScreenName;
     QDateTime m_newTime;
+
     QString m_removeScreenName;
     QDateTime m_removeTime;
 };
