@@ -82,7 +82,7 @@ MainWindow::MainWindow(QWidget *parent)
     , m_mainPanel(new MainPanelControl(this))
     , m_platformWindowHandle(this)
     , m_wmHelper(DWindowManagerHelper::instance())
-    , m_multiScreenWorker(new MultiScreenWorker(this, m_wmHelper))
+    , m_multiScreenWorker(new MultiScreenWorker(this))
     , m_menuWorker(new MenuWorker(m_multiScreenWorker->dockInter(), this))
     , m_shadowMaskOptimizeTimer(new QTimer(this))
     , m_dbusDaemonInterface(QDBusConnection::sessionBus().interface())
@@ -220,6 +220,10 @@ void MainWindow::mousePressEvent(QMouseEvent *e)
         });
         return;
     }
+
+    if (Utils::IS_WAYLAND_DISPLAY && m_multiScreenWorker->launcherVisible()) {
+        m_multiScreenWorker->setLauncherVisble(false);
+    }
 }
 
 void MainWindow::keyPressEvent(QKeyEvent *e)
@@ -349,7 +353,7 @@ void MainWindow::initConnections()
 
     // -拖拽任务栏改变高度或宽度-------------------------------------------------------------------------------
     connect(m_updateDragAreaTimer, &QTimer::timeout, this, &MainWindow::resetDragWindow);
-    //TODO 后端考虑删除这块，目前还不能删除，调整任务栏高度的时候，任务栏外部区域有变化
+    //TODO 后面考虑删除这块，目前还不能删除，调整任务栏高度的时候，任务栏外部区域有变化
     connect(m_updateDragAreaTimer, &QTimer::timeout, m_multiScreenWorker, &MultiScreenWorker::onRequestUpdateRegionMonitor);
 
     connect(m_dragWidget, &DragWidget::dragPointOffset, this, [ = ] { qApp->setProperty(DRAG_STATE_PROP, true); });
@@ -500,6 +504,7 @@ void MainWindow::resizeDock(int offset, bool dragging)
 {
     qApp->setProperty(DRAG_STATE_PROP, dragging);
 
+    // 以任务栏的最小高度区域为参照，通过offset设置其高度或宽度
     const QRect &rect = m_multiScreenWorker->getDockShowMinGeometry(m_multiScreenWorker->deskScreen());
     QRect newRect;
     switch (m_multiScreenWorker->position()) {
