@@ -289,7 +289,8 @@ void ModuleWidget::initUI()
                                                        , {"datetime",       "dcc_dock_time"}
                                                        , {"system-monitor", "dcc_dock_systemmonitor"}
                                                        , {"grand-search",   "dcc_dock_grandsearch"}
-                                                       , {"trash",          "dcc_dock_trash"}};
+                                                       , {"trash",          "dcc_dock_trash"}
+                                                       , {"shot-start-plugin",  "shot-start-plugin"}};
         if (plugins.size() != 0) {
             layout->addSpacing(10);
             layout->addWidget(m_pluginAreaTitle);
@@ -334,7 +335,22 @@ void ModuleWidget::initUI()
 
                 // 插件图标
                 auto leftAction = new DViewItemAction(Qt::AlignVCenter, size, size, true);
-                leftAction->setIcon(QIcon::fromTheme(pluginIconMap.value(m_dockInter->getPluginKey(name), "dcc_dock_plug_in")));
+
+                const QString pluginKey = m_dockInter->getPluginKey(name);
+                QIcon pluginIcon;
+                // 第三方插件通过pluginKey从系统中读取图标
+                if (pluginIconMap.contains(pluginKey)) {
+                    pluginIcon = QIcon::fromTheme(pluginIconMap.value(m_dockInter->getPluginKey(name)));
+                } else {
+                    pluginIcon = QIcon::fromTheme(pluginKey);
+                }
+
+                // 如果获取不到图标则使用默认图标
+                if (pluginIcon.isNull()) {
+                    pluginIcon = QIcon::fromTheme("dcc_dock_plug_in");
+                }
+
+                leftAction->setIcon(pluginIcon);
                 item->setActionList(Qt::Edge::LeftEdge, {leftAction});
 
                 auto rightAction = new DViewItemAction(Qt::AlignVCenter, size, size, true);
@@ -362,7 +378,7 @@ void ModuleWidget::initUI()
     }
 
     // 支持在触摸屏上滚动
-    QScroller::grabGesture(this->window(), QScroller::LeftMouseButtonGesture);
+    QScroller::grabGesture(this->viewport(), QScroller::LeftMouseButtonGesture);
     QScroller *scroller = QScroller::scroller(this->window());
     QScrollerProperties sp;
     sp.setScrollMetric(QScrollerProperties::VerticalOvershootPolicy, QScrollerProperties::OvershootAlwaysOff);
