@@ -532,7 +532,6 @@ void SoundApplet::activePort(const QString &portId, const uint &cardId)
     for (Port *it : m_ports) {
         if (it->id() == portId && it->cardId() == cardId) {
             it->setIsActive(true);
-            enableDevice(true);
         }
         else {
             it->setIsActive(false);
@@ -558,9 +557,7 @@ void SoundApplet::enableDevice(bool flag)
         m_volumeSlider->setEnabled(flag);
     }
     m_volumeIconMin->setEnabled(flag);
-    m_soundShow->setEnabled(flag);
     m_volumeIconMax->setEnabled(flag);
-    m_deviceLabel->setEnabled(flag);
 }
 
 void SoundApplet::disableAllDevice()
