@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2018 ~ 2028 Uniontech Technology Co., Ltd.
+ * Copyright (C) 2018 ~ 2020 Uniontech Technology Co., Ltd.
  *
  * Author:     fanpengcheng <fanpengcheng@uniontech.com>
  *
@@ -29,24 +29,12 @@
 #include "imageutil.h"
 
 class Test_ImageUtil : public QObject, public ::testing::Test
-{
-public:
-    virtual void SetUp() override;
-    virtual void TearDown() override;
-
-};
-
-void Test_ImageUtil::SetUp()
-{
-}
-
-void Test_ImageUtil::TearDown()
-{
-}
+{};
 
 TEST_F(Test_ImageUtil, coverage_test)
 {
     ASSERT_TRUE(ImageUtil::loadSvg("test", QSize(100, 100), 1.5).isNull());
-    ASSERT_EQ(ImageUtil::loadSvg("dde-printer", ":/res/dde-calendar.svg", 100, 1.25).size(), QSize(125, 125));
+    ASSERT_FALSE(ImageUtil::loadSvg(":/res/dde-calendar.svg", QSize(100, 100), 1.5).isNull());
+    ASSERT_EQ(ImageUtil::loadSvg(":/res/dde-calendar.svg", "dde-printer", 100, 1.25).size(), QSize(125, 125));
     ASSERT_EQ(ImageUtil::loadSvg("123", "456", 100, 1.25).size(), QSize(125, 125));
 }
