@@ -17,7 +17,7 @@
     <name>AirplaneModeItem</name>
     <message>
         <source>Airplane mode enabled</source>
-        <translation type="unfinished"/>
+        <translation>Lentotila käytössä</translation>
     </message>
     <message>
         <source>Turn off</source>
@@ -33,7 +33,7 @@
     </message>
     <message>
         <source>Airplane mode disabled</source>
-        <translation type="unfinished"/>
+        <translation>Lentotila pois käytöstä</translation>
     </message>
 </context>
 <context>
@@ -121,6 +121,69 @@
         <translation>Aika-asetukset</translation>
     </message>
 </context>
+<context>
+    <name>DatetimeWidget</name>
+    <message>
+        <source>Monday</source>
+        <translation>Maanantai</translation>
+    </message>
+    <message>
+        <source>Tuesday</source>
+        <translation>Tiistai</translation>
+    </message>
+    <message>
+        <source>Wednesday</source>
+        <translation>Keskiviikko</translation>
+    </message>
+    <message>
+        <source>Thursday</source>
+        <translation>Torstai</translation>
+    </message>
+    <message>
+        <source>Friday</source>
+        <translation>Perjantai</translation>
+    </message>
+    <message>
+        <source>Saturday</source>
+        <translation>Lauantai</translation>
+    </message>
+    <message>
+        <source>Sunday</source>
+        <translation>Sunnuntai</translation>
+    </message>
+    <message>
+        <source>monday</source>
+        <translation>maanantai</translation>
+    </message>
+    <message>
+        <source>tuesday</source>
+        <translation>tiistai</translation>
+    </message>
+    <message>
+        <source>wednesday</source>
+        <translation>keskiviikko</translation>
+    </message>
+    <message>
+        <source>thursday</source>
+        <translation>torstai</translation>
+    </message>
+    <message>
+        <source>friday</source>
+        <translation>perjantai</translation>
+    </message>
+    <message>
+        <source>saturday</source>
+        <translation>lauantai</translation>
+    </message>
+    <message>
+        <source>sunday</source>
+        <translation>sunnuntai</translation>
+    </message>
+    <message>
+        <source>%1year%2month%3day</source>
+        <translation>%3day%2month%1year</translation>
+    </message>
+</context>
 <context>
     <name>DialogManager</name>
     <message>
@@ -248,14 +311,20 @@
     <message>
         <source>Size</source>
         <translation>Koko</translation>
+        <extra-child_page>Dock</extra-child_page>
+        <extra-contents_path>/personalization/Dock</extra-contents_path>
     </message>
     <message>
         <source>Multiple Displays</source>
         <translation>Useita näyttöjä</translation>
+        <extra-child_page>Dock</extra-child_page>
+        <extra-contents_path>/personalization/Dock</extra-contents_path>
     </message>
     <message>
         <source>Plugin Area</source>
         <translation>Laajennusalue</translation>
+        <extra-child_page>Dock</extra-child_page>
+        <extra-contents_path>/personalization/Dock</extra-contents_path>
     </message>
     <message>
         <source>Select which icons appear in the Dock</source>
@@ -272,6 +341,8 @@
     <message>
         <source>Mode</source>
         <translation>Tila</translation>
+        <extra-child_page>Dock</extra-child_page>
+        <extra-contents_path>/personalization/Dock</extra-contents_path>
     </message>
     <message>
         <source>Top</source>
@@ -292,6 +363,8 @@
     <message>
         <source>Location</source>
         <translation>Sijainti</translation>
+        <extra-child_page>Dock</extra-child_page>
+        <extra-contents_path>/personalization/Dock</extra-contents_path>
     </message>
     <message>
         <source>Keep shown</source>
@@ -308,6 +381,8 @@
     <message>
         <source>Status</source>
         <translation>Tila</translation>
+        <extra-child_page>Dock</extra-child_page>
+        <extra-contents_path>/personalization/Dock</extra-contents_path>
     </message>
     <message>
         <source>Small</source>
@@ -400,7 +475,30 @@
     <message>
         <source>Dock</source>
         <translation>Telakka</translation>
-        <extra-contents_path>/personalization/Dock</extra-contents_path>
+    </message>
+    <message>
+        <source>Mode</source>
+        <translation>Tila</translation>
+    </message>
+    <message>
+        <source>Location</source>
+        <translation>Sijainti</translation>
+    </message>
+    <message>
+        <source>Status</source>
+        <translation>Tila</translation>
+    </message>
+    <message>
+        <source>Size</source>
+        <translation>Koko</translation>
+    </message>
+    <message>
+        <source>Show Dock</source>
+        <translation>Näytä telakka</translation>
+    </message>
+    <message>
+        <source>Plugin Area</source>
+        <translation>Laajennusalue</translation>
     </message>
 </context>
 <context>
@@ -456,8 +554,8 @@
 <context>
     <name>SoundApplet</name>
     <message>
-        <source>Device</source>
-        <translation>Laite</translation>
+        <source>Volume</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -478,6 +576,10 @@
         <source>Volume %1</source>
         <translation>Äänitaso: %1</translation>
     </message>
+    <message>
+        <source>No output devices</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>SoundPlugin</name>
