@@ -10,14 +10,14 @@
     <name>AirplaneModeApplet</name>
     <message>
         <source>Airplane Mode</source>
-        <translation type="unfinished"/>
+        <translation>Авиарежим</translation>
     </message>
 </context>
 <context>
     <name>AirplaneModeItem</name>
     <message>
         <source>Airplane mode enabled</source>
-        <translation type="unfinished"/>
+        <translation>Авиарежим включён</translation>
     </message>
     <message>
         <source>Turn off</source>
@@ -29,18 +29,18 @@
     </message>
     <message>
         <source>Airplane Mode settings</source>
-        <translation type="unfinished"/>
+        <translation>Настройки Авиарежима</translation>
     </message>
     <message>
         <source>Airplane mode disabled</source>
-        <translation type="unfinished"/>
+        <translation>Авиарежим выключен</translation>
     </message>
 </context>
 <context>
     <name>AirplaneModePlugin</name>
     <message>
         <source>Airplane Mode</source>
-        <translation type="unfinished"/>
+        <translation>Авиарежим</translation>
     </message>
 </context>
 <context>
@@ -121,6 +121,69 @@
         <translation>Настройки времени</translation>
     </message>
 </context>
+<context>
+    <name>DatetimeWidget</name>
+    <message>
+        <source>Monday</source>
+        <translation>Понедельник</translation>
+    </message>
+    <message>
+        <source>Tuesday</source>
+        <translation>Вторник</translation>
+    </message>
+    <message>
+        <source>Wednesday</source>
+        <translation>Среда</translation>
+    </message>
+    <message>
+        <source>Thursday</source>
+        <translation>Четверг</translation>
+    </message>
+    <message>
+        <source>Friday</source>
+        <translation>Пятница</translation>
+    </message>
+    <message>
+        <source>Saturday</source>
+        <translation>Суббота</translation>
+    </message>
+    <message>
+        <source>Sunday</source>
+        <translation>Воскресенье</translation>
+    </message>
+    <message>
+        <source>monday</source>
+        <translation>понедельник</translation>
+    </message>
+    <message>
+        <source>tuesday</source>
+        <translation>Вторник</translation>
+    </message>
+    <message>
+        <source>wednesday</source>
+        <translation>Среда</translation>
+    </message>
+    <message>
+        <source>thursday</source>
+        <translation>Четверг</translation>
+    </message>
+    <message>
+        <source>friday</source>
+        <translation>Пятница</translation>
+    </message>
+    <message>
+        <source>saturday</source>
+        <translation>Суббота</translation>
+    </message>
+    <message>
+        <source>sunday</source>
+        <translation>воскресенье</translation>
+    </message>
+    <message>
+        <source>%1year%2month%3day</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>DialogManager</name>
     <message>
@@ -240,7 +303,7 @@
     </message>
     <message>
         <source>Dock settings</source>
-        <translation type="unfinished"/>
+        <translation>Настройки Dock</translation>
     </message>
 </context>
 <context>
@@ -248,14 +311,20 @@
     <message>
         <source>Size</source>
         <translation>Размер</translation>
+        <extra-child_page>Dock</extra-child_page>
+        <extra-contents_path>/personalization/Dock</extra-contents_path>
     </message>
     <message>
         <source>Multiple Displays</source>
         <translation>Несколько Дисплеев</translation>
+        <extra-child_page>Dock</extra-child_page>
+        <extra-contents_path>/personalization/Dock</extra-contents_path>
     </message>
     <message>
         <source>Plugin Area</source>
         <translation>Область Плагина</translation>
+        <extra-child_page>Dock</extra-child_page>
+        <extra-contents_path>/personalization/Dock</extra-contents_path>
     </message>
     <message>
         <source>Select which icons appear in the Dock</source>
@@ -272,6 +341,8 @@
     <message>
         <source>Mode</source>
         <translation>Режим</translation>
+        <extra-child_page>Dock</extra-child_page>
+        <extra-contents_path>/personalization/Dock</extra-contents_path>
     </message>
     <message>
         <source>Top</source>
@@ -293,6 +364,8 @@
     <message>
         <source>Location</source>
         <translation>Расположение</translation>
+        <extra-child_page>Dock</extra-child_page>
+        <extra-contents_path>/personalization/Dock</extra-contents_path>
     </message>
     <message>
         <source>Keep shown</source>
@@ -309,6 +382,8 @@
     <message>
         <source>Status</source>
         <translation>Статус</translation>
+        <extra-child_page>Dock</extra-child_page>
+        <extra-contents_path>/personalization/Dock</extra-contents_path>
     </message>
     <message>
         <source>Small</source>
@@ -401,7 +476,30 @@
     <message>
         <source>Dock</source>
         <translation>Dock</translation>
-        <extra-contents_path>/personalization/Dock</extra-contents_path>
+    </message>
+    <message>
+        <source>Mode</source>
+        <translation>Режим</translation>
+    </message>
+    <message>
+        <source>Location</source>
+        <translation>Расположение</translation>
+    </message>
+    <message>
+        <source>Status</source>
+        <translation>Статус</translation>
+    </message>
+    <message>
+        <source>Size</source>
+        <translation>Размер</translation>
+    </message>
+    <message>
+        <source>Show Dock</source>
+        <translation>Показывать Dock</translation>
+    </message>
+    <message>
+        <source>Plugin Area</source>
+        <translation>Область Плагина</translation>
     </message>
 </context>
 <context>
@@ -457,8 +555,8 @@
 <context>
     <name>SoundApplet</name>
     <message>
-        <source>Device</source>
-        <translation>Устройство</translation>
+        <source>Volume</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -479,6 +577,10 @@
         <source>Volume %1</source>
         <translation>Громкость %1</translation>
     </message>
+    <message>
+        <source>No output devices</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>SoundPlugin</name>
